@@ -205,7 +205,7 @@ interface.
 
 Fundamental types for representing data passed across the API.
 
-### km_core_cp type
+### km_core_cu type
 
 `uint16_t/char16_t`
 
@@ -683,7 +683,7 @@ KMN_API
 km_core_context_status
 km_core_state_context_set_if_needed(
   km_core_state *state,
-  km_core_cp const *application_context
+  km_core_cu const *application_context
 );
 
 /*
@@ -800,8 +800,8 @@ Platform layer.
 ## Specification
 ```c */
 struct km_core_option_item {
-  km_core_cp const *   key;
-  km_core_cp const *   value;
+  km_core_cu const *   key;
+  km_core_cu const *   value;
   uint8_t             scope;
 };
 
@@ -860,8 +860,8 @@ KMN_API
 km_core_status
 km_core_state_option_lookup(km_core_state const *state,
                       uint8_t scope,
-                      km_core_cp const *key,
-                      km_core_cp const **value);
+                      km_core_cu const *key,
+                      km_core_cu const **value);
 
 /*
 ```
@@ -1005,9 +1005,13 @@ Provides read-only information about a keyboard.
 ```c
 */
 typedef struct {
-  km_core_cp const * version_string;
-  km_core_cp const * id;
+  km_core_cu const * version_string;
+  km_core_cu const * id;
+
+  // TODO-web-core: Deprecate this field (#12497)
+  // KMN_DEPRECATED
   km_core_path_name  folder_path;
+
   km_core_option_item const * default_options;
 } km_core_keyboard_attrs;
 
@@ -1022,7 +1026,7 @@ typedef struct {
 : Keyman keyboard ID string.
 
 `folder_path`
-: Path to the unpacked folder containing the keyboard and associated resources.
+: Path to the unpacked folder containing the keyboard and associated resources (deprecated).
 
 `default_options`
 : Set of default values for any options included in the keyboard.
@@ -1070,8 +1074,8 @@ Describes a single Input Method eXtension library and entry point.
 
 ```c */
 typedef struct {
-  km_core_cp const * library_name;
-  km_core_cp const * function_name;
+  km_core_cu const * library_name;
+  km_core_cu const * function_name;
   uint32_t imx_id;
 } km_core_keyboard_imx;
 
@@ -1092,29 +1096,35 @@ typedef struct {
 
 -------------------------------------------------------------------------------
 
-# km_core_keyboard_load()
+# km_core_keyboard_load_from_blob()
 
 ## Description
 
-Parse and load keyboard from the supplied path and a pointer to the loaded keyboard
+Parse and load keyboard from the supplied blob and a pointer to the loaded keyboard
 into the out paramter.
 
 ## Specification
 
 ```c */
 KMN_API
-km_core_status
-km_core_keyboard_load(km_core_path_name kb_path,
-                     km_core_keyboard **keyboard);
+km_core_status km_core_keyboard_load_from_blob(const km_core_path_name kb_name,
+                                               const void* blob,
+                                               const size_t blob_size,
+                                               km_core_keyboard** keyboard);
 
 /*
 ```
 
 ## Parameters
 
-`kb_path`
-: On Windows, a UTF-16 string; on other platforms, a C string:
-  contains a valid path to the keyboard file.
+`kb_name`
+: a string with the name of the keyboard.
+
+`blob`
+: a byte array containing the content of a KMX/KMX+ file.
+
+`blob_size`
+: a size_t variable with the size of the blob in bytes.
 
 `keyboard`
 : A pointer to result variable: A pointer to the opaque keyboard
@@ -1133,7 +1143,7 @@ km_core_keyboard_load(km_core_path_name kb_path,
 : In the event the keyboard file is unparseable for any reason
 
 `KM_CORE_STATUS_INVALID_ARGUMENT`
-: In the event the file doesn't exist or is inaccesible or `keyboard` is null.
+: In the event `keyboard` is null.
 
 `KM_CORE_STATUS_OS_ERROR`
 : Bit 31 (high bit) set, bits 0-30 are an OS-specific error code.
@@ -1145,7 +1155,7 @@ km_core_keyboard_load(km_core_path_name kb_path,
 ## Description
 
 Free the allocated memory belonging to an opaque keyboard object previously
-returned by [km_core_keyboard_load].
+returned by [km_core_keyboard_load_from_blob].
 
 ## Specification
 
@@ -1332,7 +1342,7 @@ void km_core_state_imx_register_callback(km_core_state *state, km_core_keyboard_
 : pointer to a function that implements the IMX callback
 
 `callback_object`
-: An opaque pointer that can be used to pass context information to the callback function, 
+: An opaque pointer that can be used to pass context information to the callback function,
   usually it is a user-defined data structure.
 
 -------------------------------------------------------------------------------
@@ -1523,7 +1533,7 @@ Returns a debug formatted string of the context from the state.
 
 ```c */
 KMN_API
-km_core_cp *
+km_core_cu *
 km_core_state_context_debug(km_core_state *state, km_core_debug_context_type context_type);
 
 /*
@@ -1538,16 +1548,16 @@ km_core_state_context_debug(km_core_state *state, km_core_debug_context_type con
 
 ## Returns
 
-A pointer to a [km_core_cp] UTF-16 string. Must be disposed of by a call
-to [km_core_cp_dispose].
+A pointer to a [km_core_cu] UTF-16 string. Must be disposed of by a call
+to [km_core_cu_dispose].
 
 -------------------------------------------------------------------------------
 
-# km_core_cp_dispose()
+# km_core_cu_dispose()
 
 ## Description
 
-Free the allocated memory belonging to a [km_core_cp] array previously
+Free the allocated memory belonging to a [km_core_cu] array previously
 returned by [km_core_state_context_debug]. May be `nullptr`.
 
 ## Specification
@@ -1555,14 +1565,14 @@ returned by [km_core_state_context_debug]. May be `nullptr`.
 ```c */
 KMN_API
 void
-km_core_cp_dispose(km_core_cp *cp);
+km_core_cu_dispose(km_core_cu *cp);
 
 /*
 ```
 ## Parameters
 
 `cp`
-: A pointer to the start of the [km_core_cp] array to be disposed of.
+: A pointer to the start of the [km_core_cu] array to be disposed of.
 
 -------------------------------------------------------------------------------
 
