@@ -8,7 +8,6 @@
 #include <sstream>
 #include <string>
 #include <type_traits>
-#include <codecvt>
 
 #if 0
 // TODO-LDML If we need to avoid exceptions in JSON
@@ -19,6 +18,9 @@
 
 #include <json.hpp>
 
+// Ensure that ICU gets included even on wasm.
+#define KMN_IN_LDML_TESTS
+
 #include <kmx/kmx_processevent.h> // for char to vk mapping tables
 #include <kmx/kmx_xstring.h> // for surrogate pair macros
 #include <kmx/kmx_plus.h>
@@ -29,6 +31,7 @@
 #include "path.hpp"
 #include "state.hpp"
 #include "utfcodec.hpp"
+#include "util_normalize.hpp"
 
 #include "ldml_test_source.hpp"
 #include "ldml_test_utils.hpp"
@@ -37,6 +40,11 @@
 #include "unicode/uniset.h"
 #include "unicode/usetiter.h"
 
+#include "../load_kmx_file.hpp"
+
+#include <test_assert.h>
+#include <test_color.h>
+
 #define assert_or_return(expr) if(!(expr)) { \
   std::wcerr << __FILE__ << ":" << __LINE__ << ": " << \
   console_color::fg(console_color::BRIGHT_RED) \
@@ -50,9 +58,6 @@
 namespace km {
 namespace tests {
 
-#include <test_color.h>
-
-
 
 /** string munging */
 static void append_to_str(std::u16string &str, const char *buf) {
@@ -123,9 +128,9 @@ bool LdmlTestSource::get_expected_beep() const {
 }
 
 int LdmlTestSource::load_kmx_plus(const km::core::path &compiled) {
-
-  // check and load the KMX (yes, once again)
-  if(!km::core::ldml_processor::is_kmxplus_file(compiled, rawdata)) {
+    // check and load the KMX (yes, once again)
+  rawdata = km::tests::load_kmx_file(compiled);
+  if(!km::core::ldml_processor::is_handled(rawdata)) {
     std::cerr << "Reading KMX for test purposes failed: " << compiled << std::endl;
     return __LINE__;
   }
@@ -202,37 +207,37 @@ LdmlTestSource::parse_source_string(std::string const &s) {
       p++;
       km_core_usv v;
       bool had_open_curly = false;
-      assert(p != s.end());
+      test_assert(p != s.end());
       if (*p == 'u' || *p == 'U') {
         // Unicode value
         p++;
         if (*p == '{') {
           p++;
-          assert(p != s.end());
+          test_assert(p != s.end());
           had_open_curly = true;
         }
         size_t n;
         std::string s1 = s.substr(p - s.begin(), 8);
         v              = std::stoul(s1, &n, 16);
         // Allow deadkey_number (U+0001) characters and onward
-        assert(v >= 0x0001 && v <= 0x10FFFF);
+        test_assert(v >= 0x0001 && v <= 0x10FFFF);
         p += n - 1;
         if (v < 0x10000) {
-          t += km_core_cp(v);
+          t += km_core_cu(v);
         } else {
-          t += km_core_cp(Uni_UTF32ToSurrogate1(v));
-          t += km_core_cp(Uni_UTF32ToSurrogate2(v));
+          t += km_core_cu(Uni_UTF32ToSurrogate1(v));
+          t += km_core_cu(Uni_UTF32ToSurrogate2(v));
         }
         if (had_open_curly) {
           p++;
           // close what you opened
-          assert(*p == '}'); // close curly
-          assert(p != s.end());
+          test_assert(*p == '}'); // close curly
+          test_assert(p != s.end());
         }
       } else if (*p == 'd') {
         // Deadkey
         // TODO, not yet supported
-        assert(false);
+        test_assert(false);
       }
     } else {
       t += *p;
@@ -244,46 +249,46 @@ LdmlTestSource::parse_source_string(std::string const &s) {
 std::u16string
 LdmlTestSource::parse_u8_source_string(std::string const &u8s) {
   // convert from utf-8 to utf-16 first
-  std::u16string s = std::wstring_convert<std::codecvt_utf8_utf16<char16_t>, char16_t>{}.from_bytes(u8s);
+  std::u16string s = convert<char, char16_t>(u8s);
   std::u16string t;
   for (auto p = s.begin(); p != s.end(); p++) {
     if (*p == '\\') {
       p++;
       km_core_usv v;
       bool had_open_curly = false;
-      assert(p != s.end());
+      test_assert(p != s.end());
       if (*p == 'u' || *p == 'U') {
         // Unicode value
         p++;
         if (*p == '{') {
           p++;
-          assert(p != s.end());
+          test_assert(p != s.end());
           had_open_curly = true;
         }
         size_t n;
         std::u16string s1 = s.substr(p - s.begin(), 8);
         // TODO-LDML: convert back first?
-        std::string s1b = std::wstring_convert<std::codecvt_utf8_utf16<char16_t>, char16_t>{}.to_bytes(s1);
+        std::string s1b = convert<char16_t, char>(s1);
         v              = std::stoul(s1b, &n, 16);
         // Allow deadkey_number (U+0001) characters and onward
-        assert(v >= 0x0001 && v <= 0x10FFFF);
+        test_assert(v >= 0x0001 && v <= 0x10FFFF);
         p += n - 1;
         if (v < 0x10000) {
-          t += km_core_cp(v);
+          t += km_core_cu(v);
         } else {
-          t += km_core_cp(Uni_UTF32ToSurrogate1(v));
-          t += km_core_cp(Uni_UTF32ToSurrogate2(v));
+          t += km_core_cu(Uni_UTF32ToSurrogate1(v));
+          t += km_core_cu(Uni_UTF32ToSurrogate2(v));
         }
         if (had_open_curly) {
           p++;
           // close what you opened
-          assert(*p == '}'); // close curly
-          assert(p != s.end());
+          test_assert(*p == '}'); // close curly
+          test_assert(p != s.end());
         }
       } else if (*p == 'd') {
         // Deadkey
         // TODO, not yet supported
-        assert(false);
+        test_assert(false);
       }
     } else {
       t += *p;
@@ -400,7 +405,7 @@ LdmlTestSource::set_caps_lock_on(bool caps_lock_on) {
 
 key_event
 LdmlTestSource::char_to_event(char ch) {
-  assert(ch >= 32);
+  test_assert(ch >= 32);
   return {
       km::core::kmx::s_char_to_vkey[(int)ch - 32].vk,
       (uint16_t)(km::core::kmx::s_char_to_vkey[(int)ch - 32].shifted ? KM_CORE_MODIFIER_SHIFT : 0)};
@@ -440,7 +445,7 @@ LdmlEmbeddedTestSource::vkey_to_event(std::string const &vk_event) {
       if (vk == 0) {
         std::cerr << "Error parsing [" << vk_event << "] - could not find vkey or modifier: " << s << std::endl;
       }
-      assert(vk != 0);
+      test_assert(vk != 0);
       break; // only one vkey allowed
     }
   }
@@ -448,9 +453,9 @@ LdmlEmbeddedTestSource::vkey_to_event(std::string const &vk_event) {
   // The string should be empty at this point
   if (std::getline(f, s, ' ')) {
     std::cerr << "Error parsing vkey ["<<vk_event<<"] - excess string after key: " << s << std::endl;
-    assert(false);
+    test_assert(false);
   }
-  assert(vk != 0);
+  test_assert(vk != 0);
 
   return {vk, modifier_state};
 }
@@ -499,7 +504,7 @@ LdmlEmbeddedTestSource::parse_next_key(std::string &keys) {
       return char_to_event(ch);
     }
     auto n = keys.find(']');
-    assert(n != std::string::npos);
+    test_assert(n != std::string::npos);
     auto vkey = keys.substr(1, n - 1);
     keys.erase(0, n + 1);
     return vkey_to_event(vkey);
@@ -543,11 +548,11 @@ LdmlJsonTestSource::~LdmlJsonTestSource() {
 bool LdmlJsonTestSource::set_key_from_id(key_event& k, const std::u16string& id) {
   k = {0, 0};  // set to a null value at first.
 
-  assert(kmxplus != nullptr);
+  test_assert(kmxplus != nullptr);
   // lookup the id
-  assert(kmxplus->key2 != nullptr);
+  test_assert(kmxplus->key2 != nullptr);
 
-  assert(kmxplus->key2Helper.valid());
+  test_assert(kmxplus->key2Helper.valid());
   // First, find the string
   KMX_DWORD strId = kmxplus->strs->find(id);
   if (strId == 0) {
@@ -564,7 +569,7 @@ bool LdmlJsonTestSource::set_key_from_id(key_event& k, const std::u16string& id)
   // Now, look for the _first_ candidate vkey match in the kmap.
   for (KMX_DWORD kmapIndex = 0; kmapIndex < kmxplus->key2->kmapCount; kmapIndex++) {
     auto *kmap = kmxplus->key2Helper.getKmap(kmapIndex);
-    assert(kmap != nullptr);
+    test_assert(kmap != nullptr);
     if (kmap->key == keyIndex) {
       k = {(km_core_virtual_key)kmap->vkey, (uint16_t)kmap->mod};
       return true;
@@ -603,7 +608,7 @@ LdmlJsonTestSource::next_action(ldml_action &fillin) {
     fillin.type   = LDML_ACTION_CHECK_EXPECTED;
     fillin.string = LdmlTestSource::parse_u8_source_string(result.get<std::string>());
     if (!get_normalization_disabled()) {
-      assert(km::core::ldml::normalize_nfd(fillin.string)); // TODO-LDML: will be NFC when core is normalizing to NFC
+      test_assert(km::core::util::normalize_nfd(fillin.string)); // TODO-LDML: will be NFC when core is normalizing to NFC
     }
     return;
   } else if (type == "keystroke") {
@@ -618,7 +623,7 @@ LdmlJsonTestSource::next_action(ldml_action &fillin) {
     fillin.type   = LDML_ACTION_EMIT_STRING;
     fillin.string = LdmlTestSource::parse_u8_source_string(to.get<std::string>());
     if (!get_normalization_disabled()) {
-      assert(km::core::ldml::normalize_nfd(fillin.string)); // TODO-LDML: will be NFC when core is normalizing to NFC
+      test_assert(km::core::util::normalize_nfd(fillin.string)); // TODO-LDML: will be NFC when core is normalizing to NFC
     }
     return;
   } else if (type == "backspace") {
@@ -645,7 +650,7 @@ LdmlJsonTestSource::get_context() {
     auto startContext = data["/startContext/to"_json_pointer];
     context = LdmlTestSource::parse_u8_source_string(startContext);
     if (!get_normalization_disabled()) {
-      assert(km::core::ldml::normalize_nfd(context)); // TODO-LDML: should be NFC
+      test_assert(km::core::util::normalize_nfd(context)); // TODO-LDML: should be NFC
     }
   }
   loaded_context = true;
@@ -717,7 +722,7 @@ LdmlJsonRepertoireTestSource::next_action(ldml_action &fillin) {
   std::size_t len = km::core::kmx::Utf32CharToUtf16(ch, ch16);
   std::u16string chstr = std::u16string(ch16.ch, len);
   if (!get_normalization_disabled()) {
-    assert(km::core::ldml::normalize_nfd(chstr)); // TODO-LDML: will be NFC when core is normalizing to NFC
+    test_assert(km::core::util::normalize_nfd(chstr)); // TODO-LDML: will be NFC when core is normalizing to NFC
   }
   // append to expected
   expected.append(chstr);
@@ -728,14 +733,14 @@ LdmlJsonRepertoireTestSource::next_action(ldml_action &fillin) {
   // TODO-LDML: no transforms yet.
   // TODO-LDML: looking for an exact single key for now
 
-  assert(kmxplus != nullptr);
+  test_assert(kmxplus != nullptr);
   // lookup the id
-  assert(kmxplus->strs != nullptr);
-  assert(kmxplus->key2 != nullptr);
-  assert(kmxplus->layr != nullptr);
+  test_assert(kmxplus->strs != nullptr);
+  test_assert(kmxplus->key2 != nullptr);
+  test_assert(kmxplus->layr != nullptr);
 
-  assert(kmxplus->key2Helper.valid());
-  assert(kmxplus->layrHelper.valid());
+  test_assert(kmxplus->key2Helper.valid());
+  test_assert(kmxplus->layrHelper.valid());
 
   // First, find the string as an id
   // TODO-LDML: will not work for multi string cases
@@ -752,7 +757,7 @@ LdmlJsonRepertoireTestSource::next_action(ldml_action &fillin) {
   // Now, look for the _first_ candidate vkey match in the kmap.
   for (KMX_DWORD kmapIndex = 0; kmapIndex < kmxplus->key2->kmapCount; kmapIndex++) {
     auto *kmap = kmxplus->key2Helper.getKmap(kmapIndex);
-    assert(kmap != nullptr);
+    test_assert(kmap != nullptr);
     if (kmap->key == keyIndex) {
       fillin.k = {(km_core_virtual_key)kmap->vkey, (uint16_t)kmap->mod};
       std::cout << "found vkey " << fillin.k.vk << ":" << fillin.k.modifier_state << std::endl;
