@@ -7,8 +7,11 @@
 extern "C" {
 #endif
 
+void initialize_keyman_system_service_client();
 void set_capslock_indicator(guint32 capsLockState);
 gint32 get_capslock_indicator();
+void call_ordered_output_sentinel();
+void ping_keyman_system_service();
 
 #ifdef __cplusplus
 }
